@@ -1,9 +1,10 @@
+import os
 import sys
 from importlib import metadata as importlib_metadata
 from pathlib import Path
 
 project = "micropip"
-copyright = "2019-2022, Pyodide contributors and Mozilla"
+copyright = "2019-2025, Pyodide contributors and Mozilla"
 # author = "Pyodide Authors"
 
 # -- General configuration ---------------------------------------------------
@@ -18,26 +19,30 @@ extensions = [
 ]
 
 intersphinx_mapping = {
-    "python": ("https://docs.python.org/3.10", None),
+    "python": ("https://docs.python.org/3.13", None),
     "pyodide": ("https://pyodide.org/en/stable/", None),
 }
 
 templates_path = ["_templates"]
 exclude_patterns = ["_build", "Thumbs.db", ".*"]
 
+
+# -- Options for HTML output -------------------------------------------------
+# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
+html_baseurl = os.environ.get("READTHEDOCS_CANONICAL_URL", "")
+
 html_css_files = [
     "css/pyodide.css",
 ]
 
-# -- Options for HTML output -------------------------------------------------
-# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
-
-sys.path.append(Path(__file__).parent.parent.as_posix())
-
 html_theme = "sphinx_book_theme"
 html_logo = "_static/img/pyodide-logo.png"
 html_static_path = ["_static"]
 
+
+sys.path.append(Path(__file__).parent.parent.as_posix())
+
+
 try:
     release = importlib_metadata.version("micropip")
 except importlib_metadata.PackageNotFoundError:
